@@ -38,7 +38,9 @@ IPNAMESPACE = "BuiltinIPNamespace"
 IPADDRESS = "BuiltinIPAddress"
 IPADDRESSPOOL = "CoreIPAddressPool"
 IPPREFIX = "BuiltinIPPrefix"
+IPPREFIXAVAILABLE = "InternalIPPrefixAvailable"
 IPPREFIXPOOL = "CoreIPPrefixPool"
+IPRANGEAVAILABLE = "InternalIPRangeAvailable"
 MENU = "CoreMenu"
 MENUITEM = "CoreMenuItem"
 NAMESPACE = "IpamNamespace"
