@@ -35,6 +35,6 @@ class Migration009(InternalSchemaMigration):
         ]
         return cls(migrations=migrations, **kwargs)  # type: ignore[arg-type]
 
-    async def validate_migration(self, db: InfrahubDatabase) -> MigrationResult:
+    async def validate_migration(self, db: InfrahubDatabase) -> MigrationResult:  # noqa: ARG002
         result = MigrationResult()
         return result
