@@ -3,6 +3,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Any
 
 from infrahub import config
+from infrahub.core.constants import GLOBAL_BRANCH_NAME
 from infrahub.core.query import Query, QueryType
 
 if TYPE_CHECKING:
@@ -21,33 +22,49 @@ class DeleteBranchRelationshipsQuery(Query):
 
     async def query_init(self, db: InfrahubDatabase, **kwargs: Any) -> None:  # noqa: ARG002
         query = """
-// delete all relationships on this branch
-MATCH (s)-[r1]-(d)
-WHERE r1.branch = $branch_name
-CALL (r1) {
-  DELETE r1
-} IN TRANSACTIONS
-
-// check for any orphaned Node vertices and delete them
-WITH collect(DISTINCT s.uuid) + collect(DISTINCT d.uuid) AS nodes_uuids
-MATCH (s2:Node)-[r2]-(d2)
-WHERE NOT exists((s2)-[:IS_PART_OF]-(:Root))
-AND s2.uuid IN nodes_uuids
-CALL (r2) {
-  DELETE r2
-} IN TRANSACTIONS
-
-// reduce results to a single row
-WITH 1 AS one LIMIT 1
-
-// find any orphaned vertices and delete them
-MATCH (n)
-WHERE NOT exists((n)--())
+// --------------
+// for every Node created on this branch (it's about to be deleted), find any agnostic relationships
+// connected to the Node and delete them
+// --------------
+OPTIONAL MATCH (:Root)<-[e:IS_PART_OF {status: "active"}]-(n:Node)
+WHERE e.branch = $branch_name
 CALL (n) {
-  DELETE n
+    OPTIONAL MATCH (n)-[:IS_RELATED {branch: $global_branch_name}]-(rel:Relationship)
+    DETACH DELETE rel
+} IN TRANSACTIONS
+
+// reduce the results to a single row
+WITH 1 AS one
+LIMIT 1
+
+// --------------
+// for every edge on this branch, delete it
+// --------------
+MATCH (s)-[r]->(d)
+WHERE r.branch = $branch_name
+CALL (r) {
+    DELETE r
+} IN TRANSACTIONS
+
+// --------------
+// get the database IDs of every vertex linked to a deleted edge
+// --------------
+WITH DISTINCT elementId(s) AS s_id, elementId(d) AS d_id
+WITH collect(s_id) + collect(d_id) AS vertex_ids
+UNWIND vertex_ids AS vertex_id
+
+// --------------
+// delete any vertices that are now orphaned
+// --------------
+CALL (vertex_id) {
+    MATCH (n)
+    WHERE elementId(n) = vertex_id
+    AND NOT exists((n)--())
+    DELETE n
 } IN TRANSACTIONS
         """
         self.params["branch_name"] = self.branch_name
+        self.params["global_branch_name"] = GLOBAL_BRANCH_NAME
         self.add_to_query(query)
 
 
