@@ -5,12 +5,12 @@ from typing import TYPE_CHECKING, Any
 from infrahub_sdk.timestamp import Timestamp as BaseTimestamp
 
 if TYPE_CHECKING:
-    from pendulum.datetime import DateTime
+    from datetime import datetime
 
 
 class Timestamp(BaseTimestamp):
-    async def to_graphql(self, *args: Any, **kwargs: Any) -> DateTime:  # pylint: disable=unused-argument
-        return self.obj
+    async def to_graphql(self, *args: Any, **kwargs: Any) -> datetime:  # noqa: ARG002
+        return self.to_datetime()
 
     def get_query_filter_path(self, rel_name: str = "r") -> tuple[str, dict]:
         """
