@@ -1,15 +1,22 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from fastapi import APIRouter, Depends
 from fastapi.responses import PlainTextResponse
 from graphql import print_schema
 from starlette.routing import Route, WebSocketRoute
 
-from infrahub.api.dependencies import get_branch_dep
+from infrahub.api.dependencies import get_branch_dep, get_current_user
 from infrahub.core import registry
-from infrahub.core.branch import Branch
 from infrahub.graphql.manager import GraphQLSchemaManager
 
 from .dependencies import build_graphql_app
 
+if TYPE_CHECKING:
+    from infrahub.auth import AccountSession
+    from infrahub.core.branch import Branch
+
 router = APIRouter(redirect_slashes=False)
 
 
@@ -21,7 +28,9 @@ router.routes.append(WebSocketRoute(path="/graphql/{branch_name:str}", endpoint=
 
 
 @router.get("/schema.graphql", include_in_schema=False)
-async def get_graphql_schema(branch: Branch = Depends(get_branch_dep)) -> PlainTextResponse:
+async def get_graphql_schema(
+    branch: Branch = Depends(get_branch_dep), _: AccountSession = Depends(get_current_user)
+) -> PlainTextResponse:
     schema_branch = registry.schema.get_schema_branch(name=branch.name)
     gqlm = GraphQLSchemaManager.get_manager_for_branch(branch=branch, schema_branch=schema_branch)
     graphql_schema = gqlm.get_graphql_schema()
