@@ -74,7 +74,7 @@ class IPPrefixGetNextAvailable(ObjectType):
         root: dict,  # noqa: ARG004
         info: GraphQLResolveInfo,
         prefix_id: str,
-        prefix_length: int,
+        prefix_length: int | None = None,
     ) -> dict[str, str]:
         graphql_context: GraphqlContext = info.context
 
@@ -119,3 +119,25 @@ InfrahubIPPrefixGetNextAvailable = Field(
     resolver=IPPrefixGetNextAvailable.resolve,
     required=True,
 )
+
+# The following two query fields must be removed once we are sure that people are not using the old queries anymore. Those fields only exist to
+# expose a deprecation message.
+
+DeprecatedIPAddressGetNextAvailable = Field(
+    IPAddressGetNextAvailable,
+    prefix_id=String(required=True),
+    prefix_length=Int(required=False),
+    resolver=IPAddressGetNextAvailable.resolve,
+    required=True,
+    deprecation_reason="This query has been renamed to 'InfrahubIPAddressGetNextAvailable'. It will be removed in the next version of Infrahub.",
+)
+
+
+DeprecatedIPPrefixGetNextAvailable = Field(
+    IPPrefixGetNextAvailable,
+    prefix_id=String(required=True),
+    prefix_length=Int(required=False),
+    resolver=IPPrefixGetNextAvailable.resolve,
+    required=True,
+    deprecation_reason="This query has been renamed to 'InfrahubIPPrefixGetNextAvailable'. It will be removed in the next version of Infrahub.",
+)
