@@ -57,7 +57,7 @@ default_menu = [
                 name="IPPrefix",
                 label="IP Prefixes",
                 kind=InfrahubKind.IPPREFIX,
-                path="/ipam/prefixes",
+                path="/ipam",
                 icon=_extract_node_icon(infrahub_schema.get(InfrahubKind.IPPREFIX)),
                 protected=True,
                 section=MenuSection.INTERNAL,
@@ -68,7 +68,7 @@ default_menu = [
                 name="IPAddress",
                 label="IP Addresses",
                 kind=InfrahubKind.IPPREFIX,
-                path="/ipam/addresses?ipam-tab=ip-details",
+                path="/ipam/ip_addresses",
                 icon=_extract_node_icon(infrahub_schema.get(InfrahubKind.IPADDRESS)),
                 protected=True,
                 section=MenuSection.INTERNAL,
@@ -79,6 +79,7 @@ default_menu = [
                 name="Namespaces",
                 label="Namespaces",
                 kind=InfrahubKind.IPNAMESPACE,
+                path="/ipam/namespaces",
                 icon=_extract_node_icon(infrahub_schema.get(InfrahubKind.IPNAMESPACE)),
                 protected=True,
                 section=MenuSection.INTERNAL,
@@ -246,6 +247,37 @@ default_menu = [
                 section=MenuSection.INTERNAL,
                 order_weight=2000,
             ),
+            MenuItemDefinition(
+                namespace="Builtin",
+                name="TriggerDefinition",
+                label="Events",
+                icon=_extract_node_icon(infrahub_schema.get(InfrahubKind.TRIGGERRULE)),
+                protected=True,
+                section=MenuSection.INTERNAL,
+                order_weight=6000,
+                children=[
+                    MenuItemDefinition(
+                        namespace="Builtin",
+                        name="TriggerRule",
+                        label="Rules",
+                        kind=InfrahubKind.TRIGGERRULE,
+                        icon=_extract_node_icon(infrahub_schema.get(InfrahubKind.TRIGGERRULE)),
+                        protected=True,
+                        section=MenuSection.INTERNAL,
+                        order_weight=1000,
+                    ),
+                    MenuItemDefinition(
+                        namespace="Builtin",
+                        name="Action",
+                        label="Actions",
+                        kind=InfrahubKind.ACTION,
+                        icon=_extract_node_icon(infrahub_schema.get(InfrahubKind.ACTION)),
+                        protected=True,
+                        section=MenuSection.INTERNAL,
+                        order_weight=2000,
+                    ),
+                ],
+            ),
         ],
     ),
     MenuItemDefinition(
